==> zio-aws-inspector2_2.12-5.17.233.1-sources.jar: zio/aws/inspector2/model/ListCoverageResponse.scala <==
package zio.aws.inspector2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.inspector2.model.primitives.NextToken
import scala.jdk.CollectionConverters._
final case class ListCoverageResponse(
    coveredResources: Optional[
      Iterable[zio.aws.inspector2.model.CoveredResource]
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.inspector2.model.ListCoverageResponse = {
    import ListCoverageResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.inspector2.model.ListCoverageResponse
      .builder()
      .optionallyWith(
        coveredResources.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.coveredResources)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.inspector2.model.ListCoverageResponse.ReadOnly =
    zio.aws.inspector2.model.ListCoverageResponse.wrap(buildAwsValue())
}
object ListCoverageResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.inspector2.model.ListCoverageResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.inspector2.model.ListCoverageResponse =
      zio.aws.inspector2.model.ListCoverageResponse(
        coveredResources.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def coveredResources
        : Optional[List[zio.aws.inspector2.model.CoveredResource.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getCoveredResources: ZIO[Any, AwsError, List[
      zio.aws.inspector2.model.CoveredResource.ReadOnly
    ]] = AwsError.unwrapOptionField("coveredResources", coveredResources)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.inspector2.model.ListCoverageResponse
  ) extends zio.aws.inspector2.model.ListCoverageResponse.ReadOnly {
    override val coveredResources
        : Optional[List[zio.aws.inspector2.model.CoveredResource.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.coveredResources())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.inspector2.model.CoveredResource.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.inspector2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.inspector2.model.ListCoverageResponse
  ): zio.aws.inspector2.model.ListCoverageResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-inspector2_2.13-5.17.121.3-sources.jar: zio/aws/inspector2/model/ListCoverageResponse.scala <==
package zio.aws.inspector2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.inspector2.model.primitives.NextToken
import scala.jdk.CollectionConverters._
final case class ListCoverageResponse(
    coveredResources: Option[
      Iterable[zio.aws.inspector2.model.CoveredResource]
    ] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.inspector2.model.ListCoverageResponse = {
    import ListCoverageResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.inspector2.model.ListCoverageResponse
      .builder()
      .optionallyWith(
        coveredResources.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.coveredResources)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.inspector2.model.ListCoverageResponse.ReadOnly =
    zio.aws.inspector2.model.ListCoverageResponse.wrap(buildAwsValue())
}
object ListCoverageResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.inspector2.model.ListCoverageResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.inspector2.model.ListCoverageResponse =
      zio.aws.inspector2.model.ListCoverageResponse(
        coveredResources.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def coveredResources
        : Option[List[zio.aws.inspector2.model.CoveredResource.ReadOnly]]
    def nextToken: Option[NextToken]
    def getCoveredResources: ZIO[Any, AwsError, List[
      zio.aws.inspector2.model.CoveredResource.ReadOnly
    ]] = AwsError.unwrapOptionField("coveredResources", coveredResources)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.inspector2.model.ListCoverageResponse
  ) extends zio.aws.inspector2.model.ListCoverageResponse.ReadOnly {
    override val coveredResources
        : Option[List[zio.aws.inspector2.model.CoveredResource.ReadOnly]] =
      scala
        .Option(impl.coveredResources())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.inspector2.model.CoveredResource.wrap(item)
          }.toList
        )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.inspector2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.inspector2.model.ListCoverageResponse
  ): zio.aws.inspector2.model.ListCoverageResponse.ReadOnly = new Wrapper(impl)
}
